import random
import string
import random

class Vs():
    def __init__(self):
        self.version = 0.1


class Generator():
    def __init__(self):

        #Nitro Generator

        self.tyx = "ABCDEFGHIJKLMNOPQRSTUVWYXZabcdefghijklmnopqrstuvwxyz123456789"
        self.a1 = random.choice(self.tyx)
        self.a2 = random.choice(self.tyx)
        self.a3 = random.choice(self.tyx)
        self.a4 = random.choice(self.tyx)
        self.a5 = random.choice(self.tyx)
        self.a6 = random.choice(self.tyx)
        self.a7 = random.choice(self.tyx)
        self.a8 = random.choice(self.tyx)
        self.a9 = random.choice(self.tyx)
        self.a10 = random.choice(self.tyx)
        self.a11 = random.choice(self.tyx)
        self.a12 = random.choice(self.tyx)
        self.a13 = random.choice(self.tyx)
        self.a14 = random.choice(self.tyx)
        self.a15 = random.choice(self.tyx)
        self.a16 = random.choice(self.tyx)
        self.nitro = "https://discord.gift/" + self.a1+self.a2+self.a3+self.a4+self.a5+self.a6+self.a7+self.a8+self.a9+self.a10+self.a11+self.a12+self.a13+self.a14+self.a15+self.a16